@@ -67,7 +67,6 @@ class AdvancedApiKeyManager:
                 - "all": Find all GEMINI_API_KEY_* environment variables
                 - Integer (e.g., 5): Search for GEMINI_API_KEY_1, GEMINI_API_KEY_2, ..., GEMINI_API_KEY_5
                 - Range string (e.g., "1-15"): Search for GEMINI_API_KEY_1 through GEMINI_API_KEY_15
-                - Single string: Use as single environment variable name
             paid_keys (str | list[str] | None): 
                 - "all": All keys are paid
                 - List of strings: Environment variable names of paid keys (e.g., ["GEMINI_API_KEY_1", "GEMINI_API_KEY_3"])
@@ -267,6 +266,30 @@ class AdvancedApiKeyManager:
                     keys.append(value)
                     key_to_env_name[value] = env_var
                     logging.debug(f"Found API key from environment variable '{env_var}'.")
+        elif isinstance(keylist_names, str) and '-' in keylist_names:
+            # Handle range notation (e.g., "1-15")
+            try:
+                parts = keylist_names.split('-')
+                if len(parts) == 2 and parts[0].isdigit() and parts[1].isdigit():
+                    start_num = int(parts[0])
+                    end_num = int(parts[1])
+                    if start_num <= end_num:
+                        logging.info(f"Searching for keys GEMINI_API_KEY_{start_num} through GEMINI_API_KEY_{end_num}...")
+                        for i in range(start_num, end_num + 1):
+                            key_name = f"GEMINI_API_KEY_{i}"
+                            key = os.getenv(key_name)
+                            if key and len(key) > 10:
+                                keys.append(key)
+                                key_to_env_name[key] = key_name
+                                logging.debug(f"Loaded key from {key_name}.")
+                            else:
+                                logging.debug(f"Environment variable '{key_name}' not found or invalid.")
+                    else:
+                        logging.warning(f"Invalid range '{keylist_names}': start ({start_num}) should be <= end ({end_num})")
+                else:
+                    logging.warning(f"Invalid range format '{keylist_names}'. Expected format: 'start-end' (e.g., '1-15')")
+            except Exception as e:
+                logging.error(f"Error parsing range '{keylist_names}': {e}")
         elif isinstance(keylist_names, (int, str)) and str(keylist_names).isdigit():
             # Handle numeric input: search GEMINI_API_KEY_1, GEMINI_API_KEY_2, ..., GEMINI_API_KEY_n
             num_keys = int(keylist_names)
@@ -290,17 +313,6 @@ class AdvancedApiKeyManager:
                     logging.debug(f"Loaded key from {key_name}.")
                 else:
                     logging.warning(f"Environment variable '{key_name}' not found or invalid.")
-        else:
-            # Handle single key name
-            key_names = [keylist_names] if isinstance(keylist_names, str) else keylist_names
-            for key_name in key_names:
-                key = os.getenv(key_name)
-                if key and len(key) > 10:
-                    keys.append(key)
-                    key_to_env_name[key] = key_name
-                    logging.debug(f"Loaded key from {key_name}.")
-                else:
-                    logging.warning(f"Environment variable '{key_name}' not found or invalid.")
         
         logging.info(f"Successfully loaded {len(keys)} valid API keys.")
         return keys, key_to_env_name
@@ -314,7 +326,6 @@ class AdvancedApiKeyManager:
             - keylist_names = "all"  # Find all GEMINI_API_KEY_* environment variables
             - keylist_names = 5  # Load GEMINI_API_KEY_1, GEMINI_API_KEY_2, ..., GEMINI_API_KEY_5
             - keylist_names = "1-15"  # Load GEMINI_API_KEY_1 through GEMINI_API_KEY_15
-            - keylist_names = "SINGLE_KEY"  # Single key name
         """
         keys = []
         
@@ -346,21 +357,9 @@ class AdvancedApiKeyManager:
                     else:
                         logging.warning(f"Invalid range '{keylist_names}': start ({start_num}) should be <= end ({end_num})")
                 else:
-                    # Not a valid range format, treat as single key name
-                    key = os.getenv(keylist_names)
-                    if key and len(key) > 10:
-                        keys.append(key)
-                        logging.debug(f"Loaded key from {keylist_names}.")
-                    else:
-                        logging.warning(f"Environment variable '{keylist_names}' not found or invalid.")
+                    logging.warning(f"Invalid range format '{keylist_names}'. Expected format: 'start-end' (e.g., '1-15')")
             except Exception as e:
-                logging.warning(f"Error parsing range '{keylist_names}': {e}. Treating as single key name.")
-                key = os.getenv(keylist_names)
-                if key and len(key) > 10:
-                    keys.append(key)
-                    logging.debug(f"Loaded key from {keylist_names}.")
-                else:
-                    logging.warning(f"Environment variable '{keylist_names}' not found or invalid.")
+                logging.error(f"Error parsing range '{keylist_names}': {e}")
         elif isinstance(keylist_names, (int, str)) and str(keylist_names).isdigit():
             # Handle numeric input: search GEMINI_API_KEY_1, GEMINI_API_KEY_2, ..., GEMINI_API_KEY_n
             num_keys = int(keylist_names)
@@ -382,16 +381,6 @@ class AdvancedApiKeyManager:
                     logging.debug(f"Loaded key from {key_name}.")
                 else:
                     logging.warning(f"Environment variable '{key_name}' not found or invalid.")
-        else:
-            # Handle single key name
-            key_names = [keylist_names] if isinstance(keylist_names, str) else keylist_names
-            for key_name in key_names:
-                key = os.getenv(key_name)
-                if key and len(key) > 10:
-                    keys.append(key)
-                    logging.debug(f"Loaded key from {key_name}.")
-                else:
-                    logging.warning(f"Environment variable '{key_name}' not found or invalid.")
         
         logging.info(f"Successfully loaded {len(keys)} valid API keys.")
         return keys
